@@ -9,10 +9,11 @@ import warnings
 import os
 import sys
 import struct
+
 try:
     from typing import Literal
 except ImportError:
-    from type_extensions import Literal
+    from typing_extensions import Literal
 
 import mando
 from mando.rst_text_formatter import RSTHelpFormatter
@@ -113,6 +114,9 @@ def _get_data(binfilename, interval="daily", labels=[",,,"], catalog_only=True):
         intervalcode = None
 
     # Fixup and test the labels - could be in it's own function
+    if isinstance(labels, str):
+        labels = labels.split(" ")
+    labels = tsutils.flatten(labels)
     for lindex, label in enumerate(labels):
         words = [lindex] + label.split(",")
         if len(words) != 5:
@@ -371,7 +375,12 @@ def extract_cli(hbnfilename, interval, *labels, **kwds):
 
 
 @typic.al
-def extract(hbnfilename: str, interval: Literal["yearly", "monthly", "daily", "BIVL"], *labels, **kwds):
+def extract(
+    hbnfilename: str,
+    interval: Literal["yearly", "monthly", "daily", "BIVL"],
+    *labels,
+    **kwds
+):
     r"""Returns a DataFrame from a HSPF binary output file."""
     try:
         time_stamp = kwds.pop("time_stamp")
@@ -515,7 +524,7 @@ def dump_cli(hbnfilename, time_stamp="begin"):
 
 
 @typic.al
-def dump(hbnfilename: str, time_stamp: Literal["begin", "end"]="begin"):
+def dump(hbnfilename: str, time_stamp: Literal["begin", "end"] = "begin"):
     """
     Prints out ALL data from a HSPF binary output file.
     """
@@ -552,15 +561,13 @@ The "time_stamp" optional keyword must be either
 
 @mando.command()
 def about():
-    """Display version number and system information.
-    """
+    """Display version number and system information."""
     tsutils.about(__name__)
 
 
 @mando.command
 def time_series(hbnfilename, interval, *labels, **kwds):
-    """ DEPRECATED: Use 'extract' instead.
-    """
+    """DEPRECATED: Use 'extract' instead."""
     return extract(hbnfilename, interval, *labels, **kwds)
 
 
